beeld.metadata


apertureclj

(aperture x)

captionclj

(caption x)

compressionclj

(compression x)

compression-typeclj

(compression-type x)

data-precisionclj

(data-precision x)

description-exifclj

(description-exif x)

description-xmpclj

(description-xmp x)

exif-tagcljmacro

(exif-tag x directory tag)

x can be any argument that clojure.java.io/input-stream supports, ie. InputStream, File, URI, URL, Socket, byte array, and String arguments. If the argument is a String, it tries to resolve it first as a URI, then as a local file name. URIs with a 'file' protocol are converted to local file names.

x can be any argument that clojure.java.io/input-stream supports, ie. InputStream, File, URI, URL, Socket, byte array, and String arguments. If the argument is a String, it tries to resolve it first as a URI, then as a local file name.  URIs with a 'file' protocol are converted to local file names.
raw docstring

exposure-timeclj

(exposure-time x)

filenameclj

(filename x)

fnumberclj

(fnumber x)

focal-lengthclj

(focal-length x)

geolocationclj

(geolocation x)

get-tag-by-nameclj


gps-dateclj

(gps-date x)

image-heightclj

(image-height x)

image-widthclj

(image-width x)

isoclj

(iso x)

lensclj

(lens x)

lens-makeclj

(lens-make x)

lens-modelclj

(lens-model x)

lens-specificationclj

(lens-specification x)

makeclj

(make x)

mime-typeclj

(mime-type x)

modelclj

(model x)

number-of-tagsclj

(number-of-tags x)

orientationclj

(orientation x)

original-dateclj

(original-date x)

shutter-speedclj

(shutter-speed x)

simulationclj

(simulation x)

tagsclj

(tags x)

Map of maps

Map of maps
raw docstring

tags*clj

(tags* x)

Vector of maps

Vector of maps
raw docstring

tags**clj

(tags** x)

Sequence of Tag objects

Sequence of Tag objects
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries