(aperture x)(caption x)(compression x)(compression-type x)(data-precision x)(description-exif x)(description-xmp x)(exif-tag x directory tag)x can be any argument that clojure.java.io/input-stream supports, ie. InputStream, File, URI, URL, Socket, byte array, and String arguments. If the argument is a String, it tries to resolve it first as a URI, then as a local file name. URIs with a 'file' protocol are converted to local file names.
x can be any argument that clojure.java.io/input-stream supports, ie. InputStream, File, URI, URL, Socket, byte array, and String arguments. If the argument is a String, it tries to resolve it first as a URI, then as a local file name. URIs with a 'file' protocol are converted to local file names.
(exposure-time x)(filename x)(fnumber x)(focal-length x)(geolocation x)(gps-date x)(image-height x)(image-width x)(iso x)(lens x)(lens-make x)(lens-model x)(lens-specification x)(make x)(mime-type x)(model x)(number-of-tags x)(orientation x)(original-date x)(shutter-speed x)(simulation x)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |